@@ -1,11 +1,11 @@
 use strict;
 use warnings;
-package Dist::Zilla::Plugin::MakeMaker::Fallback; # git description: v0.018-2-g1d9de72
+package Dist::Zilla::Plugin::MakeMaker::Fallback; # git description: v0.019-8-gd573830
 # ABSTRACT: Generate a Makefile.PL containing a warning for legacy users
 # KEYWORDS: plugin installer MakeMaker Makefile.PL toolchain legacy ancient backcompat
 # vim: set ts=8 sts=4 sw=4 tw=115 et :
 
-our $VERSION = '0.019';
+our $VERSION = '0.020';
 
 use Moose;
 extends 'Dist::Zilla::Plugin::MakeMaker::Awesome' => { -version => '0.15' };
@@ -92,11 +92,7 @@ my @missing = grep {
     ! eval "require $_; $_->VERSION($configure_requires{$_}); 1"
 } keys %configure_requires;
 
-if (not @missing)
-{
-    print "Congratulations, your toolchain understands 'configure_requires'!\n\n";
-}
-else
+if (@missing)
 {
     if (not $ENV{PERL_MM_FALLBACK_SILENCE_WARNING})
     {
@@ -164,12 +160,12 @@ __PACKAGE__->meta->make_immutable;
 #pod This plugin is a derivative of C<[MakeMaker]>, generating a F<Makefile.PL> in
 #pod your dist, with an added preamble that is printed when it is run:
 #pod
-#pod =over 4
-#pod
 #pod =for stopwords cpanminus mb
 #pod
 #pod =for comment This section was inserted from the DATA section at build time
 #pod
+#pod =begin :verbatim
+#pod
 #pod *** WARNING WARNING WARNING WARNING WARNING WARNING WARNING WARNING ***
 #pod
 #pod If you're seeing this warning, your toolchain is really, really old* and you'll
@@ -203,7 +199,7 @@ __PACKAGE__->meta->make_immutable;
 #pod PERL_MM_FALLBACK_SILENCE_WARNING environment variable.
 #pod
 #pod
-#pod =back
+#pod =end :verbatim
 #pod
 #pod =for stopwords ModuleBuildTiny
 #pod
@@ -257,7 +253,7 @@ Dist::Zilla::Plugin::MakeMaker::Fallback - Generate a Makefile.PL containing a w
 
 =head1 VERSION
 
-version 0.019
+version 0.020
 
 =head1 SYNOPSIS
 
@@ -273,47 +269,43 @@ C<configure_requires>:
 This plugin is a derivative of C<[MakeMaker]>, generating a F<Makefile.PL> in
 your dist, with an added preamble that is printed when it is run:
 
-=over 4
-
 =for Pod::Coverage after_build build test
 
 =for stopwords cpanminus mb
 
 =for comment This section was inserted from the DATA section at build time
 
-*** WARNING WARNING WARNING WARNING WARNING WARNING WARNING WARNING ***
+    *** WARNING WARNING WARNING WARNING WARNING WARNING WARNING WARNING ***
 
-If you're seeing this warning, your toolchain is really, really old* and you'll
-almost certainly have problems installing CPAN modules from this century. But
-never fear, dear user, for we have the technology to fix this!
+    If you're seeing this warning, your toolchain is really, really old* and you'll
+    almost certainly have problems installing CPAN modules from this century. But
+    never fear, dear user, for we have the technology to fix this!
 
-If you're using CPAN.pm to install things, then you can upgrade it using:
+    If you're using CPAN.pm to install things, then you can upgrade it using:
 
     cpan CPAN
 
-If you're using CPANPLUS to install things, then you can upgrade it using:
+    If you're using CPANPLUS to install things, then you can upgrade it using:
 
     cpanp CPANPLUS
 
-If you're using cpanminus, you shouldn't be seeing this message in the first
-place, so please file an issue on github.
+    If you're using cpanminus, you shouldn't be seeing this message in the first
+    place, so please file an issue on github.
 
-If you're installing manually, please retrain your fingers to run Build.PL
-when present instead.
+    If you're installing manually, please retrain your fingers to run Build.PL
+    when present instead.
 
-This public service announcement was brought to you by the Perl Toolchain
-Gang, the irc.perl.org #toolchain IRC channel, and the number 42.
+    This public service announcement was brought to you by the Perl Toolchain
+    Gang, the irc.perl.org #toolchain IRC channel, and the number 42.
 
-----
+    ----
 
-* Alternatively, you are doing something overly clever, in which case you
-should consider setting the 'prefer_installer' config option in CPAN.pm, or
-'prefer_makefile' in CPANPLUS, to 'mb" and '0' respectively.
+    * Alternatively, you are doing something overly clever, in which case you
+    should consider setting the 'prefer_installer' config option in CPAN.pm, or
+    'prefer_makefile' in CPANPLUS, to 'mb" and '0' respectively.
 
-You can also silence this warning for future installations by setting the
-PERL_MM_FALLBACK_SILENCE_WARNING environment variable.
-
-=back
+    You can also silence this warning for future installations by setting the
+    PERL_MM_FALLBACK_SILENCE_WARNING environment variable.
 
 =for stopwords ModuleBuildTiny
 
@@ -370,7 +362,7 @@ L<Dist::Zilla::Plugin::ModuleBuildTiny::Fallback>
 
 Karen Etheridge <ether@cpan.org>
 
-=head1 COPYRIGHT AND LICENSE
+=head1 COPYRIGHT AND LICENCE
 
 This software is copyright (c) 2013 by Karen Etheridge.
 
